==> seedsui-react-5.7.84.tgz: package/lib/Modal/Picker/Head/Submit.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["visible", "caption", "disabled", "total"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React from 'react';
import locale from "./../../../locale";
import { jsxs as _jsxs } from "react/jsx-runtime";
var Submit = function Submit(_ref) {
  var submitProps = _ref.submitProps,
    onSubmitClick = _ref.onSubmitClick;
  var _ref2 = submitProps || {},
    visible = _ref2.visible,
    submitCaption = _ref2.caption,
    submitDisabled = _ref2.disabled,
    total = _ref2.total,
    otherSubmitProps = _objectWithoutProperties(_ref2, _excluded);

  // 点击确定
  function handleSubmitClick(e) {
    e.stopPropagation();
    if (submitProps !== null && submitProps !== void 0 && submitProps.onClick) submitProps === null || submitProps === void 0 ? void 0 : submitProps.onClick(e);
    if (onSubmitClick) onSubmitClick(e);
  }
  return /*#__PURE__*/_jsxs("div", _objectSpread(_objectSpread({}, otherSubmitProps), {}, {
    className: "picker-submit".concat(otherSubmitProps.className ? ' ' + otherSubmitProps.className : '').concat(submitDisabled === true ? ' disabled' : ''),
    onClick: handleSubmitClick,
    children: [submitCaption || locale('确定', 'ok'), typeof total === 'number' && "(".concat(total, ")")]
  }));
};
export default Submit;

==> seedsui-react-5.8.90.tgz: package/lib/Modal/Picker/Head/Submit.js <==
var _excluded = ["visible", "caption", "disabled", "total"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React from 'react';

// 内库使用
import locale from "./../../../locale";

// 测试使用
// import { locale } from 'seedsui-react'

var Submit = function Submit(_ref) {
  var submitProps = _ref.submitProps,
    onSubmitClick = _ref.onSubmitClick;
  var _ref2 = submitProps || {},
    visible = _ref2.visible,
    submitCaption = _ref2.caption,
    submitDisabled = _ref2.disabled,
    total = _ref2.total,
    otherSubmitProps = _objectWithoutProperties(_ref2, _excluded);

  // 点击确定
  function handleSubmitClick(e) {
    e.stopPropagation();
    if (submitProps !== null && submitProps !== void 0 && submitProps.onClick) submitProps === null || submitProps === void 0 || submitProps.onClick(e);
    if (onSubmitClick) onSubmitClick(e);
  }
  return /*#__PURE__*/React.createElement("div", _extends({}, otherSubmitProps, {
    className: "picker-submit".concat(otherSubmitProps.className ? ' ' + otherSubmitProps.className : '').concat(submitDisabled === true ? ' disabled' : ''),
    onClick: handleSubmitClick
  }), submitCaption || locale('确定', 'SeedsUI_ok'), typeof total === 'number' && "(".concat(total, ")"));
};
export default Submit;
